==> plantuml_1.2017.15.orig.tar.gz: plantuml-1.2017.15/src/net/sourceforge/plantuml/LineParam.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 * 
 */
package net.sourceforge.plantuml;


public enum LineParam {
//	sequenceBoundaryBorder,
	sequenceActorBorder,
	sequenceDividerBorder,
//	sequenceGroupBorder(0.1),
//	sequenceReferenceBorder(0.1),
	sequenceLifeLineBorder,
	sequenceParticipantBorder, noteBorder, sequenceGroupBorder, sequenceReferenceBorder,
	legendBorder,
	sequenceArrow,
	classBorder, objectBorder, usecaseBorder,
	partitionBorder,
	packageBorder,
	swimlaneBorder,
	activityBorder,
	titleBorder,
	diagramBorder,
	rectangleBorder;
//	sequenceBoxBorder(0.1);
	
}

==> plantuml-1.2022.2.tar.gz: plantuml-1.2022.2/src/net/sourceforge/plantuml/LineParam.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2023, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 * 
 */
package net.sourceforge.plantuml;


public enum LineParam {
//	sequenceBoundaryBorder,
	sequenceActorBorder,
	sequenceDividerBorder,
//	sequenceGroupBorder(0.1),
//	sequenceReferenceBorder(0.1),
	sequenceLifeLineBorder,
	sequenceParticipantBorder, noteBorder, sequenceGroupBorder, sequenceReferenceBorder,
	legendBorder,
	sequenceArrow,
	arrow,
	classBorder, objectBorder, usecaseBorder,
	partitionBorder,
	packageBorder,
	swimlaneBorder,
	activityBorder,
	titleBorder,
	diagramBorder,
	rectangleBorder,
	hexagonBorder,
	personBorder,
	archimateBorder,
	componentBorder,
	cardBorder,
	queueBorder,
	agentBorder,
	domainBorder, designedDomainBorder, machineBorder, requirementBorder;
//	sequenceBoxBorder(0.1);
	
}
